@@ -1,8 +1,12 @@
+mod declick;
+mod smooth;
 mod time;
 
 pub mod atomic_float;
 pub mod block_buffer;
-pub mod pcm;
 pub mod decibel;
+pub mod pcm;
 
+pub use declick::*;
+pub use smooth::*;
 pub use time::*;
